Sagents.ProcessSupervisor (Sagents v0.5.1)
Copy MarkdownAbstraction over dynamic supervisor implementations.
Supports two backends:
:local— Elixir'sDynamicSupervisor(single-node):horde—Horde.DynamicSupervisor(distributed cluster)
Configuration
# Single-node (default — no config needed)
config :sagents, :distribution, :local
# Distributed cluster
config :sagents, :distribution, :horde
# Horde options (optional)
config :sagents, :horde,
members: :auto,
distribution_strategy: Horde.UniformDistribution
Summary
Functions
Returns the child spec for the agents dynamic supervisor.
Count children of the specified supervisor.
Returns the configured distribution type (:local or :horde).
Returns the child spec for the filesystem dynamic supervisor.
Start a child process under the specified supervisor.
Returns the supervisor module (DynamicSupervisor or Horde.DynamicSupervisor).
Terminate a child process.
List all children of the specified supervisor.
Functions
Returns the child spec for the agents dynamic supervisor.
Used in Sagents.Application supervision tree.
Count children of the specified supervisor.
Returns the configured distribution type (:local or :horde).
Returns the child spec for the filesystem dynamic supervisor.
Used in Sagents.Application supervision tree.
Start a child process under the specified supervisor.
Returns the supervisor module (DynamicSupervisor or Horde.DynamicSupervisor).
Terminate a child process.
List all children of the specified supervisor.